@@ -1,11 +1,12 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve.pm 66568 2008-07-22T08:57:03.423222Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve.pm 72444 2008-09-08T14:22:07.736880Z daisuke  $
 
 package Data::Valve;
 use Moose;
 use Data::Valve::Bucket;
+use Scalar::Util ();
 
 use XSLoader;
-our $VERSION   = '0.00007';
+our $VERSION   = '0.00008';
 our $AUTHORITY = 'cpan:DMAKI';
 
 XSLoader::load __PACKAGE__, $VERSION;
@@ -44,7 +45,7 @@ sub BUILDARGS {
     my ($self, %args) = @_;
 
     my $store = delete $args{bucket_store} || { module => 'Memory' };
-    if (! blessed $store) {
+    if (! Scalar::Util::blessed($store) ) {
         my $module = $store->{module};
         if ($module !~ s/^\+//) {
             $module = "Data::Valve::BucketStore::$module";
